@@ -5,7 +5,16 @@ fileStatus <- function(repo, testPath) {
   testStatus <- NULL
   
   # need to get top level path for repo
-  repoRoot <- sub("/\\.git/*", "", repo@path,  fixed = FALSE)
+  # try S4 call first, then S3
+  repoPath <- ifelse(isS4(repo),
+    try(repo@path, silent = TRUE),
+    try(repo$path, silent = TRUE))
+  
+  if(class(repoPath) == "try-error") {
+    return(infoNotFound())
+  }
+  
+  repoRoot <- sub("/\\.git/*", "", repoPath,  fixed = FALSE)
   
   statusVals <- unlist(git2r::status(repo))
   hasStatus <-  normalizePath(testPath, mustWork = FALSE) == 
