@@ -4,21 +4,22 @@
 #' or NULL if path is not available
 #' 
 #' @param absolute Return absolute path (absolute = TRUE, default) or path relative
-#' to working directory
+#' to working directory (FALSE)
 #' 
 #' @aliases get_scriptpath
 #' 
-#' @examples 
-#' mypath <- getScriptPath()
-#' 
+#' @examples
+#' \dontrun{ 
+#' mypath <- getScriptPath() 
+#' }
+#'
 #' @export
 #' 
 getScriptPath <- function(absolute = TRUE) {
-  # location of script can depend on how it was invoked:
-  # source() and knit() put it in sys.calls()
-  
   path <- NULL
   
+  # location of script can depend on how it was invoked:
+  # source() and knit() put it in sys.calls()
   if(!is.null(sys.calls())) {
     # get name of script - hope this is consistent!
     path <- as.character(sys.call(1))[2] 
@@ -29,10 +30,12 @@ getScriptPath <- function(absolute = TRUE) {
     path <- args
   }
   
+  if(is.null(path) | is.na(path)) {
+    stop("No path information available.")
+  }
+  
   if ( !(grepl(".+[R|Rmd|Rnw]$", path, perl=TRUE, ignore.case = TRUE)) )  {
-    warning("Obtained value for path <", path, "> does not end with .R, .Rmd or .Rnw: ", path)
-
-    return(NA)
+    stop("Obtained value for path <", path, "> does not end with .R, .Rmd or .Rnw: ", path)
   }
   
   # expand ~ if any
